@@ -4,7 +4,7 @@ import IJulia
 
 const TEST_FILES = [
     "install.jl", "comm.jl", "msg.jl", "execute_request.jl", "stdio.jl",
-    "inline.jl", "completion.jl"
+    "inline.jl", "completion.jl", "kernel.jl"
 ]
 
 for file in TEST_FILES
@@ -12,13 +12,6 @@ for file in TEST_FILES
     include(file)
 end
 
-# MicroMamba (and thus CondaPkg and PythonCall) are not supported on 32bit
-if Sys.WORD_SIZE != 32
-    include("kernel.jl")
-else
-    @warn "Skipping the Kernel tests on 32bit"
-end
-
 @testset "Aqua.jl" begin
     # Note that Pkg and Conda are loaded lazily
     Aqua.test_all(IJulia; stale_deps=(; ignore=[:Pkg, :Conda]))
